@@ -30,7 +30,7 @@ namespace Model
   class DeletedObject
   {
   public:
-    AWS_S3CRT_API DeletedObject();
+    AWS_S3CRT_API DeletedObject() = default;
     AWS_S3CRT_API DeletedObject(const Aws::Utils::Xml::XmlNode& xmlNode);
     AWS_S3CRT_API DeletedObject& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
 
@@ -41,14 +41,12 @@ namespace Model
     /**
      * <p>The name of the deleted object.</p>
      */
-    inline const Aws::String& GetKey() const{ return m_key; }
+    inline const Aws::String& GetKey() const { return m_key; }
     inline bool KeyHasBeenSet() const { return m_keyHasBeenSet; }
-    inline void SetKey(const Aws::String& value) { m_keyHasBeenSet = true; m_key = value; }
-    inline void SetKey(Aws::String&& value) { m_keyHasBeenSet = true; m_key = std::move(value); }
-    inline void SetKey(const char* value) { m_keyHasBeenSet = true; m_key.assign(value); }
-    inline DeletedObject& WithKey(const Aws::String& value) { SetKey(value); return *this;}
-    inline DeletedObject& WithKey(Aws::String&& value) { SetKey(std::move(value)); return *this;}
-    inline DeletedObject& WithKey(const char* value) { SetKey(value); return *this;}
+    template<typename KeyT = Aws::String>
+    void SetKey(KeyT&& value) { m_keyHasBeenSet = true; m_key = std::forward<KeyT>(value); }
+    template<typename KeyT = Aws::String>
+    DeletedObject& WithKey(KeyT&& value) { SetKey(std::forward<KeyT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -56,14 +54,12 @@ namespace Model
      * <p>The version ID of the deleted object.</p>  <p>This functionality is not
      * supported for directory buckets.</p> 
      */
-    inline const Aws::String& GetVersionId() const{ return m_versionId; }
+    inline const Aws::String& GetVersionId() const { return m_versionId; }
     inline bool VersionIdHasBeenSet() const { return m_versionIdHasBeenSet; }
-    inline void SetVersionId(const Aws::String& value) { m_versionIdHasBeenSet = true; m_versionId = value; }
-    inline void SetVersionId(Aws::String&& value) { m_versionIdHasBeenSet = true; m_versionId = std::move(value); }
-    inline void SetVersionId(const char* value) { m_versionIdHasBeenSet = true; m_versionId.assign(value); }
-    inline DeletedObject& WithVersionId(const Aws::String& value) { SetVersionId(value); return *this;}
-    inline DeletedObject& WithVersionId(Aws::String&& value) { SetVersionId(std::move(value)); return *this;}
-    inline DeletedObject& WithVersionId(const char* value) { SetVersionId(value); return *this;}
+    template<typename VersionIdT = Aws::String>
+    void SetVersionId(VersionIdT&& value) { m_versionIdHasBeenSet = true; m_versionId = std::forward<VersionIdT>(value); }
+    template<typename VersionIdT = Aws::String>
+    DeletedObject& WithVersionId(VersionIdT&& value) { SetVersionId(std::forward<VersionIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -76,7 +72,7 @@ namespace Model
      * with delete markers</a>.</p>  <p>This functionality is not supported for
      * directory buckets.</p> 
      */
-    inline bool GetDeleteMarker() const{ return m_deleteMarker; }
+    inline bool GetDeleteMarker() const { return m_deleteMarker; }
     inline bool DeleteMarkerHasBeenSet() const { return m_deleteMarkerHasBeenSet; }
     inline void SetDeleteMarker(bool value) { m_deleteMarkerHasBeenSet = true; m_deleteMarker = value; }
     inline DeletedObject& WithDeleteMarker(bool value) { SetDeleteMarker(value); return *this;}
@@ -89,14 +85,12 @@ namespace Model
      * header is the version ID of the object version deleted.</p>  <p>This
      * functionality is not supported for directory buckets.</p> 
      */
-    inline const Aws::String& GetDeleteMarkerVersionId() const{ return m_deleteMarkerVersionId; }
+    inline const Aws::String& GetDeleteMarkerVersionId() const { return m_deleteMarkerVersionId; }
     inline bool DeleteMarkerVersionIdHasBeenSet() const { return m_deleteMarkerVersionIdHasBeenSet; }
-    inline void SetDeleteMarkerVersionId(const Aws::String& value) { m_deleteMarkerVersionIdHasBeenSet = true; m_deleteMarkerVersionId = value; }
-    inline void SetDeleteMarkerVersionId(Aws::String&& value) { m_deleteMarkerVersionIdHasBeenSet = true; m_deleteMarkerVersionId = std::move(value); }
-    inline void SetDeleteMarkerVersionId(const char* value) { m_deleteMarkerVersionIdHasBeenSet = true; m_deleteMarkerVersionId.assign(value); }
-    inline DeletedObject& WithDeleteMarkerVersionId(const Aws::String& value) { SetDeleteMarkerVersionId(value); return *this;}
-    inline DeletedObject& WithDeleteMarkerVersionId(Aws::String&& value) { SetDeleteMarkerVersionId(std::move(value)); return *this;}
-    inline DeletedObject& WithDeleteMarkerVersionId(const char* value) { SetDeleteMarkerVersionId(value); return *this;}
+    template<typename DeleteMarkerVersionIdT = Aws::String>
+    void SetDeleteMarkerVersionId(DeleteMarkerVersionIdT&& value) { m_deleteMarkerVersionIdHasBeenSet = true; m_deleteMarkerVersionId = std::forward<DeleteMarkerVersionIdT>(value); }
+    template<typename DeleteMarkerVersionIdT = Aws::String>
+    DeletedObject& WithDeleteMarkerVersionId(DeleteMarkerVersionIdT&& value) { SetDeleteMarkerVersionId(std::forward<DeleteMarkerVersionIdT>(value)); return *this;}
     ///@}
   private:
 
@@ -106,7 +100,7 @@ namespace Model
     Aws::String m_versionId;
     bool m_versionIdHasBeenSet = false;
 
-    bool m_deleteMarker;
+    bool m_deleteMarker{false};
     bool m_deleteMarkerHasBeenSet = false;
 
     Aws::String m_deleteMarkerVersionId;
