@@ -31,7 +31,7 @@ namespace Model
   class JSONInput
   {
   public:
-    AWS_S3CRT_API JSONInput();
+    AWS_S3CRT_API JSONInput() = default;
     AWS_S3CRT_API JSONInput(const Aws::Utils::Xml::XmlNode& xmlNode);
     AWS_S3CRT_API JSONInput& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
 
@@ -42,16 +42,14 @@ namespace Model
     /**
      * <p>The type of JSON. Valid values: Document, Lines.</p>
      */
-    inline const JSONType& GetType() const{ return m_type; }
+    inline JSONType GetType() const { return m_type; }
     inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }
-    inline void SetType(const JSONType& value) { m_typeHasBeenSet = true; m_type = value; }
-    inline void SetType(JSONType&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }
-    inline JSONInput& WithType(const JSONType& value) { SetType(value); return *this;}
-    inline JSONInput& WithType(JSONType&& value) { SetType(std::move(value)); return *this;}
+    inline void SetType(JSONType value) { m_typeHasBeenSet = true; m_type = value; }
+    inline JSONInput& WithType(JSONType value) { SetType(value); return *this;}
     ///@}
   private:
 
-    JSONType m_type;
+    JSONType m_type{JSONType::NOT_SET};
     bool m_typeHasBeenSet = false;
   };
 
